import pytest
import tempfile
from kepi.daemon.spool import Spool

TEST_STRING = (
        'So she went into the garden '
        'to pick a cabbage leaf '
        'to make an apple pie'
        )

class TempSpool(tempfile.TemporaryDirectory):
    def __enter__(self):
        path = super().__enter__()
        result = Spool(
                path = path,
                )
        return result

def test_spool_add_incoming():
    with TempSpool() as ts:
        assert len(list(ts.items()))==0

        f = ts.add_incoming(
            message = TEST_STRING,
            )
        assert f.spool==ts
        assert f.message == TEST_STRING
        assert f.state == 'unverified'

        assert len(list(ts.items()))==1

        found_id, found = list(ts.items())[0]

        # you can compare with the ID and with the object
        assert found_id==f
        assert found==f
        assert found==found

        assert found_id!='wombat'

        with pytest.raises(AttributeError):
            found.spool = None

        with pytest.raises(AttributeError):
            found.local_id = None

        with pytest.raises(AttributeError):
            found.message = None

def test_spool_change_state():
    with TempSpool() as ts:
        stored = ts.add_incoming(
            message = TEST_STRING,
            )

        retrieved_id, retrieved = list(ts.items())[0]

        assert retrieved==stored
        assert retrieved_id == retrieved.local_id
        assert retrieved.state == 'unverified'

        retrieved.state = 'inbox'
        assert retrieved.state == 'inbox'

        with pytest.raises(ValueError):
            retrieved.state = 'wombat'
